# genutility

A collection of various Python utilities.

Most functionally is supported on Python Python 3.5+. However some things might only be working on Python 3.6+.
The last version which mostly worked with Python 2.7 was `0.0.59`.
